
; Copyright (c) 2005-2018 Intel Corporation
;
; Licensed under the Apache License, Version 2.0 (the "License");
; you may not use this file except in compliance with the License.
; You may obtain a copy of the License at
;
;     http:
;
; Unless required by applicable law or agreed to in writing, software
; distributed under the License is distributed on an "AS IS" BASIS,
; WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
; See the License for the specific language governing permissions and
; limitations under the License.
;
;
;
;

EXPORTS






; Copyright (c) 2005-2018 Intel Corporation
;
; Licensed under the Apache License, Version 2.0 (the "License");
; you may not use this file except in compliance with the License.
; You may obtain a copy of the License at
;
;     http:
;
; Unless required by applicable law or agreed to in writing, software
; distributed under the License is distributed on an "AS IS" BASIS,
; WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
; See the License for the specific language governing permissions and
; limitations under the License.
;
;
;
;











































































































































































































































































    
    

    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    









































































    














































































    




    









        
    







    
    


        
    




















    











    



    



    



    









    



    



    







    







    



    



    

















    




        
    







    

















































































    

    










































    
    











    
    
    





















    
    




































__TBB_machine_cmpswp8



__TBB_machine_fetchadd8



__TBB_machine_fetchstore8
__TBB_machine_store8
__TBB_machine_load8
__TBB_machine_trylockbyte
__TBB_machine_try_lock_elided
__TBB_machine_unlock_elided
__TBB_machine_is_in_transaction


?NFS_Allocate@internal@tbb@@YAPAXIIPAX@Z
?NFS_GetLineSize@internal@tbb@@YAIXZ
?NFS_Free@internal@tbb@@YAXPAX@Z
?allocate_via_handler_v3@internal@tbb@@YAPAXI@Z
?deallocate_via_handler_v3@internal@tbb@@YAXPAX@Z
?is_malloc_used_v3@internal@tbb@@YA_NXZ


?allocate@allocate_additional_child_of_proxy@internal@tbb@@QBEAAVtask@3@I@Z
?allocate@allocate_child_proxy@internal@tbb@@QBEAAVtask@3@I@Z
?allocate@allocate_continuation_proxy@internal@tbb@@QBEAAVtask@3@I@Z
?allocate@allocate_root_proxy@internal@tbb@@SAAAVtask@3@I@Z
?destroy@task_base@internal@interface5@tbb@@SAXAAVtask@4@@Z
?free@allocate_additional_child_of_proxy@internal@tbb@@QBEXAAVtask@3@@Z
?free@allocate_child_proxy@internal@tbb@@QBEXAAVtask@3@@Z
?free@allocate_continuation_proxy@internal@tbb@@QBEXAAVtask@3@@Z
?free@allocate_root_proxy@internal@tbb@@SAXAAVtask@3@@Z
?internal_set_ref_count@task@tbb@@AAEXH@Z
?internal_decrement_ref_count@task@tbb@@AAEHXZ
?is_owned_by_current_thread@task@tbb@@QBE_NXZ
?note_affinity@task@tbb@@UAEXG@Z
?resize@affinity_partitioner_base_v3@internal@tbb@@AAEXI@Z
?self@task@tbb@@SAAAV12@XZ
?spawn_and_wait_for_all@task@tbb@@QAEXAAVtask_list@2@@Z
?default_num_threads@task_scheduler_init@tbb@@SAHXZ
?initialize@task_scheduler_init@tbb@@QAEXHI@Z
?initialize@task_scheduler_init@tbb@@QAEXH@Z
?terminate@task_scheduler_init@tbb@@QAEXXZ
?internal_blocking_terminate@task_scheduler_init@tbb@@AAE_N_N@Z

?observe@task_scheduler_observer_v3@internal@tbb@@QAEX_N@Z



?internal_max_concurrency@task_arena_base@internal@interface7@tbb@@KAHPBVtask_arena@34@@Z
?internal_current_slot@task_arena_base@internal@interface7@tbb@@KAHXZ
?internal_initialize@task_arena_base@internal@interface7@tbb@@IAEXXZ
?internal_terminate@task_arena_base@internal@interface7@tbb@@IAEXXZ
?internal_attach@task_arena_base@internal@interface7@tbb@@IAEXXZ
?internal_enqueue@task_arena_base@internal@interface7@tbb@@IBEXAAVtask@4@H@Z
?internal_execute@task_arena_base@internal@interface7@tbb@@IBEXAAVdelegate_base@234@@Z
?internal_wait@task_arena_base@internal@interface7@tbb@@IBEXXZ

?isolate_within_arena@internal@interface7@tbb@@YAXAAVdelegate_base@123@H@Z




?destroy@task@tbb@@QAEXAAV12@@Z




?allocate@allocate_root_with_context_proxy@internal@tbb@@QBEAAVtask@3@I@Z
?free@allocate_root_with_context_proxy@internal@tbb@@QBEXAAVtask@3@@Z
?change_group@task@tbb@@QAEXAAVtask_group_context@2@@Z
?is_group_execution_cancelled@task_group_context@tbb@@QBE_NXZ
?cancel_group_execution@task_group_context@tbb@@QAE_NXZ
?reset@task_group_context@tbb@@QAEXXZ
?capture_fp_settings@task_group_context@tbb@@QAEXXZ
?init@task_group_context@tbb@@IAEXXZ
?register_pending_exception@task_group_context@tbb@@QAEXXZ
??1task_group_context@tbb@@QAE@XZ

?set_priority@task_group_context@tbb@@QAEXW4priority_t@2@@Z
?priority@task_group_context@tbb@@QBE?AW4priority_t@2@XZ

?name@captured_exception@tbb@@UBEPBDXZ
?what@captured_exception@tbb@@UBEPBDXZ
??1captured_exception@tbb@@UAE@XZ
?move@captured_exception@tbb@@UAEPAV12@XZ
?destroy@captured_exception@tbb@@UAEXXZ
?set@captured_exception@tbb@@QAEXPBD0@Z
?clear@captured_exception@tbb@@QAEXXZ



?throw_bad_last_alloc_exception_v4@internal@tbb@@YAXXZ
?throw_exception_v4@internal@tbb@@YAXW4exception_id@12@@Z
?what@bad_last_alloc@tbb@@UBEPBDXZ
?what@missing_wait@tbb@@UBEPBDXZ
?what@invalid_multiple_scheduling@tbb@@UBEPBDXZ
?what@improper_lock@tbb@@UBEPBDXZ
?what@user_abort@tbb@@UBEPBDXZ


?assertion_failure@tbb@@YAXPBDH00@Z
?get_initial_auto_partitioner_divisor@internal@tbb@@YAIXZ
?handle_perror@internal@tbb@@YAXHPBD@Z
?set_assertion_handler@tbb@@YAP6AXPBDH00@ZP6AX0H00@Z@Z
?runtime_warning@internal@tbb@@YAXPBDZZ
TBB_runtime_interface_version


?itt_load_pointer_with_acquire_v3@internal@tbb@@YAPAXPBX@Z
?itt_store_pointer_with_release_v3@internal@tbb@@YAXPAX0@Z
?call_itt_notify_v5@internal@tbb@@YAXHPAX@Z
?itt_set_sync_name_v3@internal@tbb@@YAXPAXPB_W@Z
?itt_load_pointer_v3@internal@tbb@@YAPAXPBX@Z
?itt_make_task_group_v7@internal@tbb@@YAXW4itt_domain_enum@12@PAX_K12W4string_index@12@@Z
?itt_metadata_str_add_v7@internal@tbb@@YAXW4itt_domain_enum@12@PAX_KW4string_index@12@PBD@Z
?itt_relation_add_v7@internal@tbb@@YAXW4itt_domain_enum@12@PAX_KW4itt_relation@12@12@Z
?itt_task_begin_v7@internal@tbb@@YAXW4itt_domain_enum@12@PAX_K12W4string_index@12@@Z
?itt_task_end_v7@internal@tbb@@YAXW4itt_domain_enum@12@@Z
?itt_region_begin_v9@internal@tbb@@YAXW4itt_domain_enum@12@PAX_K12W4string_index@12@@Z
?itt_region_end_v9@internal@tbb@@YAXW4itt_domain_enum@12@PAX_K@Z


??0pipeline@tbb@@QAE@XZ
??1filter@tbb@@UAE@XZ
??1pipeline@tbb@@UAE@XZ
??_7pipeline@tbb@@6B@
?add_filter@pipeline@tbb@@QAEXAAVfilter@2@@Z
?clear@pipeline@tbb@@QAEXXZ
?inject_token@pipeline@tbb@@AAEXAAVtask@2@@Z
?run@pipeline@tbb@@QAEXI@Z

?run@pipeline@tbb@@QAEXIAAVtask_group_context@2@@Z

?process_item@thread_bound_filter@tbb@@QAE?AW4result_type@12@XZ
?try_process_item@thread_bound_filter@tbb@@QAE?AW4result_type@12@XZ
?set_end_of_input@filter@tbb@@IAEXXZ


?internal_construct@queuing_rw_mutex@tbb@@QAEXXZ
?acquire@scoped_lock@queuing_rw_mutex@tbb@@QAEXAAV23@_N@Z
?downgrade_to_reader@scoped_lock@queuing_rw_mutex@tbb@@QAE_NXZ
?release@scoped_lock@queuing_rw_mutex@tbb@@QAEXXZ
?upgrade_to_writer@scoped_lock@queuing_rw_mutex@tbb@@QAE_NXZ
?try_acquire@scoped_lock@queuing_rw_mutex@tbb@@QAE_NAAV23@_N@Z


?try_lock_read@reader_writer_lock@interface5@tbb@@QAE_NXZ
?try_lock@reader_writer_lock@interface5@tbb@@QAE_NXZ
?unlock@reader_writer_lock@interface5@tbb@@QAEXXZ
?lock_read@reader_writer_lock@interface5@tbb@@QAEXXZ
?lock@reader_writer_lock@interface5@tbb@@QAEXXZ
?internal_construct@reader_writer_lock@interface5@tbb@@AAEXXZ
?internal_destroy@reader_writer_lock@interface5@tbb@@AAEXXZ
?internal_construct@scoped_lock@reader_writer_lock@interface5@tbb@@AAEXAAV234@@Z
?internal_destroy@scoped_lock@reader_writer_lock@interface5@tbb@@AAEXXZ
?internal_construct@scoped_lock_read@reader_writer_lock@interface5@tbb@@AAEXAAV234@@Z
?internal_destroy@scoped_lock_read@reader_writer_lock@interface5@tbb@@AAEXXZ



?internal_acquire_reader@spin_rw_mutex@tbb@@CAXPAV12@@Z
?internal_acquire_writer@spin_rw_mutex@tbb@@CA_NPAV12@@Z
?internal_downgrade@spin_rw_mutex@tbb@@CAXPAV12@@Z
?internal_itt_releasing@spin_rw_mutex@tbb@@CAXPAV12@@Z
?internal_release_reader@spin_rw_mutex@tbb@@CAXPAV12@@Z
?internal_release_writer@spin_rw_mutex@tbb@@CAXPAV12@@Z
?internal_upgrade@spin_rw_mutex@tbb@@CA_NPAV12@@Z
?internal_try_acquire_writer@spin_rw_mutex@tbb@@CA_NPAV12@@Z
?internal_try_acquire_reader@spin_rw_mutex@tbb@@CA_NPAV12@@Z



?internal_construct@spin_rw_mutex_v3@tbb@@AAEXXZ
?internal_upgrade@spin_rw_mutex_v3@tbb@@AAE_NXZ
?internal_downgrade@spin_rw_mutex_v3@tbb@@AAEXXZ
?internal_acquire_reader@spin_rw_mutex_v3@tbb@@AAEXXZ
?internal_acquire_writer@spin_rw_mutex_v3@tbb@@AAE_NXZ
?internal_release_reader@spin_rw_mutex_v3@tbb@@AAEXXZ
?internal_release_writer@spin_rw_mutex_v3@tbb@@AAEXXZ
?internal_try_acquire_reader@spin_rw_mutex_v3@tbb@@AAE_NXZ
?internal_try_acquire_writer@spin_rw_mutex_v3@tbb@@AAE_NXZ


?internal_construct@x86_rtm_rw_mutex@internal@interface8@tbb@@AAEXXZ 
?internal_release@x86_rtm_rw_mutex@internal@interface8@tbb@@AAEXAAVscoped_lock@1234@@Z 
?internal_acquire_writer@x86_rtm_rw_mutex@internal@interface8@tbb@@AAEXAAVscoped_lock@1234@_N@Z 
?internal_acquire_reader@x86_rtm_rw_mutex@internal@interface8@tbb@@AAEXAAVscoped_lock@1234@_N@Z 
?internal_upgrade@x86_rtm_rw_mutex@internal@interface8@tbb@@AAE_NAAVscoped_lock@1234@@Z 
?internal_downgrade@x86_rtm_rw_mutex@internal@interface8@tbb@@AAE_NAAVscoped_lock@1234@@Z 
?internal_try_acquire_writer@x86_rtm_rw_mutex@internal@interface8@tbb@@AAE_NAAVscoped_lock@1234@@Z 


?internal_construct@spin_mutex@tbb@@QAEXXZ
?internal_acquire@scoped_lock@spin_mutex@tbb@@AAEXAAV23@@Z
?internal_release@scoped_lock@spin_mutex@tbb@@AAEXXZ
?internal_try_acquire@scoped_lock@spin_mutex@tbb@@AAE_NAAV23@@Z


?internal_acquire@scoped_lock@mutex@tbb@@AAEXAAV23@@Z
?internal_release@scoped_lock@mutex@tbb@@AAEXXZ
?internal_try_acquire@scoped_lock@mutex@tbb@@AAE_NAAV23@@Z
?internal_construct@mutex@tbb@@AAEXXZ
?internal_destroy@mutex@tbb@@AAEXXZ


?internal_acquire@scoped_lock@recursive_mutex@tbb@@AAEXAAV23@@Z
?internal_release@scoped_lock@recursive_mutex@tbb@@AAEXXZ
?internal_try_acquire@scoped_lock@recursive_mutex@tbb@@AAE_NAAV23@@Z
?internal_construct@recursive_mutex@tbb@@AAEXXZ
?internal_destroy@recursive_mutex@tbb@@AAEXXZ


?internal_construct@queuing_mutex@tbb@@QAEXXZ
?acquire@scoped_lock@queuing_mutex@tbb@@QAEXAAV23@@Z
?release@scoped_lock@queuing_mutex@tbb@@QAEXXZ
?try_acquire@scoped_lock@queuing_mutex@tbb@@QAE_NAAV23@@Z


?internal_construct@critical_section_v4@internal@tbb@@QAEXXZ



?internal_grow_predicate@hash_map_segment_base@internal@tbb@@QBE_NXZ


?advance@concurrent_queue_iterator_base@internal@tbb@@IAEXXZ
?assign@concurrent_queue_iterator_base@internal@tbb@@IAEXABV123@@Z
?internal_size@concurrent_queue_base@internal@tbb@@IBEHXZ
??0concurrent_queue_base@internal@tbb@@IAE@I@Z
??0concurrent_queue_iterator_base@internal@tbb@@IAE@ABVconcurrent_queue_base@12@@Z
??1concurrent_queue_base@internal@tbb@@MAE@XZ
??1concurrent_queue_iterator_base@internal@tbb@@IAE@XZ
?internal_pop@concurrent_queue_base@internal@tbb@@IAEXPAX@Z
?internal_pop_if_present@concurrent_queue_base@internal@tbb@@IAE_NPAX@Z
?internal_push@concurrent_queue_base@internal@tbb@@IAEXPBX@Z
?internal_push_if_not_full@concurrent_queue_base@internal@tbb@@IAE_NPBX@Z
?internal_set_capacity@concurrent_queue_base@internal@tbb@@IAEXHI@Z



??1concurrent_queue_iterator_base_v3@internal@tbb@@IAE@XZ
??0concurrent_queue_iterator_base_v3@internal@tbb@@IAE@ABVconcurrent_queue_base_v3@12@@Z
??0concurrent_queue_iterator_base_v3@internal@tbb@@IAE@ABVconcurrent_queue_base_v3@12@I@Z
?advance@concurrent_queue_iterator_base_v3@internal@tbb@@IAEXXZ
?assign@concurrent_queue_iterator_base_v3@internal@tbb@@IAEXABV123@@Z
??0concurrent_queue_base_v3@internal@tbb@@IAE@I@Z
??1concurrent_queue_base_v3@internal@tbb@@MAE@XZ
?internal_pop@concurrent_queue_base_v3@internal@tbb@@IAEXPAX@Z
?internal_pop_if_present@concurrent_queue_base_v3@internal@tbb@@IAE_NPAX@Z
?internal_abort@concurrent_queue_base_v3@internal@tbb@@IAEXXZ
?internal_push@concurrent_queue_base_v3@internal@tbb@@IAEXPBX@Z
?internal_push_move@concurrent_queue_base_v8@internal@tbb@@IAEXPBX@Z
?internal_push_if_not_full@concurrent_queue_base_v3@internal@tbb@@IAE_NPBX@Z
?internal_push_move_if_not_full@concurrent_queue_base_v8@internal@tbb@@IAE_NPBX@Z
?internal_size@concurrent_queue_base_v3@internal@tbb@@IBEHXZ
?internal_empty@concurrent_queue_base_v3@internal@tbb@@IBE_NXZ
?internal_set_capacity@concurrent_queue_base_v3@internal@tbb@@IAEXHI@Z
?internal_finish_clear@concurrent_queue_base_v3@internal@tbb@@IAEXXZ
?internal_throw_exception@concurrent_queue_base_v3@internal@tbb@@IBEXXZ
?assign@concurrent_queue_base_v3@internal@tbb@@IAEXABV123@@Z
?move_content@concurrent_queue_base_v8@internal@tbb@@IAEXAAV123@@Z



?internal_assign@concurrent_vector_base@internal@tbb@@IAEXABV123@IP6AXPAXI@ZP6AX1PBXI@Z4@Z
?internal_capacity@concurrent_vector_base@internal@tbb@@IBEIXZ
?internal_clear@concurrent_vector_base@internal@tbb@@IAEXP6AXPAXI@Z_N@Z
?internal_copy@concurrent_vector_base@internal@tbb@@IAEXABV123@IP6AXPAXPBXI@Z@Z
?internal_grow_by@concurrent_vector_base@internal@tbb@@IAEIIIP6AXPAXI@Z@Z
?internal_grow_to_at_least@concurrent_vector_base@internal@tbb@@IAEXIIP6AXPAXI@Z@Z
?internal_push_back@concurrent_vector_base@internal@tbb@@IAEPAXIAAI@Z
?internal_reserve@concurrent_vector_base@internal@tbb@@IAEXIII@Z



??1concurrent_vector_base_v3@internal@tbb@@IAE@XZ
?internal_assign@concurrent_vector_base_v3@internal@tbb@@IAEXABV123@IP6AXPAXI@ZP6AX1PBXI@Z4@Z
?internal_capacity@concurrent_vector_base_v3@internal@tbb@@IBEIXZ
?internal_clear@concurrent_vector_base_v3@internal@tbb@@IAEIP6AXPAXI@Z@Z
?internal_copy@concurrent_vector_base_v3@internal@tbb@@IAEXABV123@IP6AXPAXPBXI@Z@Z
?internal_grow_by@concurrent_vector_base_v3@internal@tbb@@IAEIIIP6AXPAXPBXI@Z1@Z
?internal_grow_to_at_least@concurrent_vector_base_v3@internal@tbb@@IAEXIIP6AXPAXPBXI@Z1@Z
?internal_push_back@concurrent_vector_base_v3@internal@tbb@@IAEPAXIAAI@Z
?internal_reserve@concurrent_vector_base_v3@internal@tbb@@IAEXIII@Z
?internal_compact@concurrent_vector_base_v3@internal@tbb@@IAEPAXIPAXP6AX0I@ZP6AX0PBXI@Z@Z
?internal_swap@concurrent_vector_base_v3@internal@tbb@@IAEXAAV123@@Z
?internal_throw_exception@concurrent_vector_base_v3@internal@tbb@@IBEXI@Z
?internal_resize@concurrent_vector_base_v3@internal@tbb@@IAEXIIIPBXP6AXPAXI@ZP6AX10I@Z@Z
?internal_grow_to_at_least_with_result@concurrent_vector_base_v3@internal@tbb@@IAEIIIP6AXPAXPBXI@Z1@Z


?join@tbb_thread_v3@internal@tbb@@QAEXXZ
?detach@tbb_thread_v3@internal@tbb@@QAEXXZ
?internal_start@tbb_thread_v3@internal@tbb@@AAEXP6GIPAX@Z0@Z
?allocate_closure_v3@internal@tbb@@YAPAXI@Z
?free_closure_v3@internal@tbb@@YAXPAX@Z
?hardware_concurrency@tbb_thread_v3@internal@tbb@@SAIXZ
?thread_yield_v3@internal@tbb@@YAXXZ
?thread_sleep_v3@internal@tbb@@YAXABVinterval_t@tick_count@2@@Z
?move_v3@internal@tbb@@YAXAAVtbb_thread_v3@12@0@Z
?thread_get_id_v3@internal@tbb@@YA?AVid@tbb_thread_v3@12@XZ


?internal_initialize_condition_variable@internal@interface5@tbb@@YAXAATcondvar_impl_t@123@@Z
?internal_condition_variable_wait@internal@interface5@tbb@@YA_NAATcondvar_impl_t@123@PAVmutex@3@PBVinterval_t@tick_count@3@@Z
?internal_condition_variable_notify_one@internal@interface5@tbb@@YAXAATcondvar_impl_t@123@@Z
?internal_condition_variable_notify_all@internal@interface5@tbb@@YAXAATcondvar_impl_t@123@@Z
?internal_destroy_condition_variable@internal@interface5@tbb@@YAXAATcondvar_impl_t@123@@Z


?active_value@global_control@interface9@tbb@@CAIH@Z
?internal_create@global_control@interface9@tbb@@AAEXXZ
?internal_destroy@global_control@interface9@tbb@@AAEXXZ






